@@ -7,7 +7,11 @@ def test_suite():
     return unittest.TestSuite([
 
         ztc.ZopeDocFileSuite(
-            'tests/functional.txt', package='ilrt.formalworkflow',
+            'tests/workflowprocess.txt', package='ilrt.formalworkflow',
+            test_class=base.BaseFunctionalTestCase),
+
+        ztc.ZopeDocFileSuite(
+            'tests/editorpastedelete.txt', package='ilrt.formalworkflow',
             test_class=base.BaseFunctionalTestCase),
 
         ])
